%define name            xen
%define kernel_version  2.6.18

Name:       %{name}
Version:    3.1.0
Release:    %mkrel 10
Summary:    The basic tools for managing XEN virtual machines
Group:      System/Kernel and hardware
License:    GPL
Source0:    %{name}-%{version}-src.tgz
Source1:    bash-completion
Source2:    linux-%{kernel_version}.tar.bz2
Source3:    xend.init
Source4:    xendomains.init
Patch0:     xen-3.1-fix-default-interface.patch
Patch1:     xen-3.1.0-bnx2-1.4.51b.patch
Patch2:     xen-3.1.0-memcmp.patch
Patch3:     xen-3.1.0-squashfs.patch
Patch6:     xen-3.1.2-bzimage.patch
Patch7:     xen-3.2.0-pygrub-lib64.patch
Patch401:   xen-qemu-ne2000-CVE-2007-1321.patch
Patch402:   pygrub-dont-exec.patch
Patch403:   xen-3.0.3-CVE-2007-3919.patch
Requires:   python-twisted-core
Requires:   python
Requires:   module-init-tools
Requires:   iptables
Requires:   bridge-utils
Requires:   glibc-xen
Requires:   grub
Requires:   kernel-xen = %{version}
BuildRequires:	SDL-devel
BuildRequires:	curl-devel
Buildrequires:	dev86-devel
BuildRequires:  libext2fs-devel
BuildRequires:	ncurses-devel
BuildRequires:	libpython-devel >= 2.4
BuildRequires:	zlib-devel
BuildRequires:  tetex-latex
BuildRequires:  texi2html
BuildRequires:  libvncserver-devel
Obsoletes:      xen-uptodate
BuildRoot:      %{_tmppath}/%{name}-%{version}

%description 
The basic tools for managing XEN virtual machines.

%package -n kernel-xen
Summary:    XEN kernel
Group:      System/Kernel and hardware
Requires(post):	xen
Obsoletes:  kernel-xen-uptodate

%description -n kernel-xen
XEN kernel.

%package -n kernel-xen-devel
Summary:    XEN kernel sources
Group:      System/Kernel and hardware
Requires:   kernel-xen = %{version}
Obsoletes:  kernel-xen-uptodate-devel

%description -n kernel-xen-devel
XEN kernel sources.

%package doc
Summary:    XEN documentation
Group:      System/Kernel and hardware
Obsoletes:  xen-uptodate-doc

%description doc
XEN documentation.

%prep
%setup -q -n %{name}-%{version}-src
%patch0 -p 1
%patch1 -p 1
%patch2 -p 0
%patch3 -p 1
%patch6 -p 1
%patch7 -p 1

%patch401 -p 1
%patch402 -p 1
%patch403 -p 1

%build

# clean all stuff
export CFLAGS="$CFLAGS -fno-strict-aliasing"
export HOSTCC="$HOSTCC -fno-strict-aliasing"
export LINUX_SRC_PATH=$RPM_SOURCE_DIR
export pae=y
%make kernels
%make -C tools XENFB_TOOLS=y
%make -C xen
%make -C docs


%install
rm -rf %{buildroot}
export DONT_GPRINTIFY=1
export pae=y
export DESTDIR=%{buildroot}
make linux-2.6-xen-install
make -C tools install XENFB_TOOLS=y
make -C xen install

# drop dangling symlinks
rm -f %{buildroot}/lib/modules/%{kernel_version}/{build,source}

# compress modules
find %{buildroot}/lib/modules/%{kernel_version}-xen -name "*.ko" | xargs gzip -9
/sbin/depmod -u -ae -b %{buildroot} -r \
    -F %{buildroot}/boot/System.map-%{kernel_version}-xen \
    %{kernel_version}-xen

# create modules description
pushd %{buildroot}/lib/modules/%{kernel_version}-xen
find . -name "*.ko.gz" | xargs /sbin/modinfo | \
    perl -lne 'print "$name\t$1" if $name && /^description:\s*(.*)/; $name = $1 if m!^filename:\s*(.*)\.k?o!; $name =~ s!.*/!!' \
    > modules.description
popd

# install kernel sources
install -d -m 755 %{buildroot}%{_prefix}/src
cp -r -L linux-2.6.18-xen %{buildroot}%{_prefix}/src/linux-%{kernel_version}-xen

# clean sources from useless source files
pushd %{buildroot}%{_prefix}/src/linux-%{kernel_version}-xen
for i in alpha arm arm26 avr32 blackfin cris frv h8300 ia64 mips m32r m68k m68knommu parisc powerpc ppc s390 sh sh64 v850 xtensa; do
	rm -rf arch/$i
	rm -rf include/asm-$i
done

%ifnarch %{ix86} x86_64
	rm -rf arch/i386
	rm -rf arch/x86_64
	rm -rf include/asm-i386
	rm -rf include/asm-x86_64
%endif
%ifnarch sparc sparc64
	rm -rf arch/sparc
	rm -rf arch/sparc64
	rm -rf include/asm-sparc
	rm -rf include/asm-sparc64
%endif
popd

# fix man pages
install -d -m 755 %{buildroot}%{_mandir}/man{1,5}
install -m 644 docs/man1/* %{buildroot}%{_mandir}/man1
install -m 644 docs/man5/* %{buildroot}%{_mandir}/man5

# bash completion
install -m 755 -d %{buildroot}%{_sysconfdir}/bash_completion.d
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/bash_completion.d/xen

# install doc manually
rm -rf %{buildroot}%{_docdir}/qemu
install -d -m 755 %{buildroot}%{_docdir}/%{name}
install -m 644 README %{buildroot}%{_docdir}/%{name}
install -m 644 tools/ioemu/*.html %{buildroot}%{_docdir}/%{name}
install -m 644 docs/ps/* %{buildroot}%{_docdir}/%{name}
install -m 644 docs/pdf/* %{buildroot}%{_docdir}/%{name}

# install state directory
install -d -m 755 %{buildroot}%{_localstatedir}/xend/{domains,state,storage}

# install our own init scripts
install -d -m 755 %{buildroot}%{_initrddir}
install -m 755 %{SOURCE3} %{buildroot}%{_initrddir}/xend
install -m 755 %{SOURCE4} %{buildroot}%{_initrddir}/xendomains

# delete original ones
rm -rf %{buildroot}%{_sysconfdir}/init.d

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post -n kernel-xen
# remove initrd to force regeneration
rm -f /boot/initrd-2.6.18-xen.img
/sbin/installkernel -L %{kernel_version}-xen

%preun -n kernel-xen
if [ $1 = 0 ]; then
    # uninstallation
    /sbin/installkernel -R %{kernel_version}-xen
fi

%post -n kernel-xen-devel
if [ -d /lib/modules/%{kernel_version}-xen ]; then
    ln -sf /usr/src/linux-%{kernel_version}-xen /lib/modules/%{kernel_version}-xen/build
    ln -sf /usr/src/linux-%{kernel_version}-xen /lib/modules/%{kernel_version}-xen/source
fi

%postun -n kernel-xen-devel
if [ -L /lib/modules/%{kernel_version}-xen/build ]; then
    rm -f /lib/modules/%{kernel_version}-xen/build
fi
if [ -L /lib/modules/%{kernel_version}-xen/source ]; then
    rm -f /lib/modules/%{kernel_version}-xen/source
fi

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/README
%config(noreplace) %{_sysconfdir}/sysconfig/xendomains
%config(noreplace) %{_sysconfdir}/udev/rules.d/xen-backend.rules
%config(noreplace) %{_sysconfdir}/udev/xen-backend.rules
%dir %{_sysconfdir}/xen
%{_sysconfdir}/xen/scripts
%{_sysconfdir}/xen/auto
%{_sysconfdir}/xen/qemu-ifup
%config(noreplace) %{_sysconfdir}/xen/*.sxp
%config(noreplace) %{_sysconfdir}/xen/*.xml
%config(noreplace) %{_sysconfdir}/xen/xmexample*
%{_mandir}/man*/*
%{_libdir}/xen
%if "%{_lib}" != "lib"
%{_prefix}/lib/xen
%endif
%{_libdir}/fs
%{_libdir}/python/xen
%{_libdir}/python/grub/*
%{_libdir}/python/fsimage.so
%if %{mdkversion} > 200700
%{_libdir}/python/pygrub-0.3-py2.5.egg-info
%{_libdir}/python/xen-3.0-py2.5.egg-info
%endif
%{_libdir}/libxenstore*
%{_libdir}/libxenctrl*
%{_libdir}/libxenguest*
%{_libdir}/libblktap*
%{_libdir}/libfsimage*
%{_datadir}/xen
%{_localstatedir}/xend
%{_localstatedir}/xenstored
 /var/run/xenstored
/boot/xen*
%{_initrddir}/xend
%{_initrddir}/xendomains
%{_includedir}/xen
%{_includedir}/*.h
%{_sbindir}/xenstored
%{_sbindir}/netfix
%{_sbindir}/xm
%{_sbindir}/xend
%{_sbindir}/xenperf
%{_sbindir}/xenconsoled
%{_sbindir}/xentop
%{_sbindir}/xen-bugtool
%{_sbindir}/xenbaked
%{_sbindir}/xenmon.py
%{_sbindir}/blktapctrl
%{_sbindir}/img2qcow
%{_sbindir}/qcow-create
%{_sbindir}/qcow2raw
%{_sbindir}/tapdisk
%{_sbindir}/xentrace_setmask
%{_sbindir}/xen-python-path
%{_bindir}/xenperf
%{_bindir}/xencons
%{_bindir}/lomount
%{_bindir}/xentrace
%{_bindir}/xentrace_format
%{_bindir}/xentrace_setsize
%{_bindir}/xenstore-*
%{_bindir}/pygrub
%{_bindir}/xen-detect
%{_sysconfdir}/bash_completion.d/xen

%files -n kernel-xen
%defattr(-,root,root)
/boot/*-xen
/lib/modules/%{kernel_version}-xen

%files -n kernel-xen-devel
%defattr(-,root,root)
%{_prefix}/src/linux-%{kernel_version}-xen

%files doc
%defattr(-,root,root)
%{_docdir}/%{name}/*
%exclude %{_docdir}/%{name}/README
%doc docs/ps/* docs/pdf/* tools/ioemu/*.html


%changelog
* Mon Nov 03 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.0-10mdv2008.0
+ Revision: 299649
- use our own initscripts (fix #42476)
- fix pygrub on x86_64
- bzip2 support for xen loader
- call installkernel -R on uninstallation
- remove initrd on kernel installation, to force its regeneration (fix #36670)
- re-enable squashfs support
- compress kernel modules, and created modules.description file
- backport from cooker package: add missing binaries
- fix for CVE-2007-3919

* Mon Sep 17 2007 Olivier Blin <oblin@mandriva.com> 3.1.0-2mdv2008.0
+ Revision: 89095
- make kernel-xen require xen in post script (bootloader-config only configures xen kernels if xen is installed)

* Sun Sep 02 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.0-1mdv2008.0
+ Revision: 78111
- obsoletes xen-uptodate
- merge from xen-uptodate package
- make xen-uptodate the new xen package
- really fix PAE mismatch on i586 (#32027)
- install missing %%{_localstatedir}/xend directory
- build PAE hypervisor (fix #32027)
- fix memcmp build issue
- add missing patch
- update bnx2 driver to 1.4.51b, to fix IPMI issues (see http://lists.us.dell.com/pipermail/linux-poweredge/2007-January/029054.html)
- don't mark scripts as configuration
- handle doc manually
- patch0: fix default interface guess
- installing kernel is part of kernel package post-installation, not of kernel-devel one
- updated completion
- fix file list for mdk version <= 2007
- add a bootloader entry (support is just one patch away)
- requires grub
- fix kernel source tree
- call installkernel in %%post to create initrd
- don't prepare kernel tree twice, and use sparse kernel tree as devel package content
- fix symlink handling in kernel %%post
- fix file list in kernel package
- drop init patch, merged upstream
- change dependencies: make it provide xen, so as to be usable for building other package requiring a recent xen version, hence dropping explicit conflict on regular xen package
- new version
- can't provide and conflict at once with xen
- build only one kernel
- split documentation into a subpackage
- build host and guest kernels too
- change group (fix #29868)
- LSB compliant init script

  + Thierry Vignaud <tvignaud@mandriva.com>
    - replace %%{_datadir}/man by %%{_mandir}!


* Mon Mar 19 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 3.0.3-0.20060703.5mdv2007.1
- forward port lib64 fix from 2006-branch

* Mon Dec 11 2006 Arnaud Patard <apatard@mandriva.com> 3.0.3-0.20060703.4mdv2007.1
- Rebuilt for python 2.5 
- Fix python version check and include egg-info files (G. Rousse)
- Add bash-completion support (G. Rousse)

* Wed Sep 20 2006 Arnaud Patard <apatard@mandriva.com> 3.0.3-0.20060703.3mdv2007.0
- Rebuild with ncurses 5.5-1.20051029.3mdv2007.0

* Wed Sep 13 2006 Arnaud Patard <apatard@mandriva.com> 3.0.3-0.20060703.2mdv2007.0
- Fix patch0

* Tue Jul 11 2006 Arnaud Patard <apatard@mandriva.com> 3.0.3-0.20060703.1mdv2007.0
- New snapshot

* Fri May 19 2006 Arnaud Patard <apatard@mandriva.com> 3.0-0.20060510.1mdk
- New snapshot
- Disable gprintify
- Allow to set bridge mac adress

* Tue Jan 17 2006 Arnaud Patard <apatard@mandriva.com> 3.0-0.20051213.1mdk
- New snapshot

* Mon Jan 16 2006 Stefan van der Eijk <stefan@eijk.nu> 3.0-0.20050823.7mdk
- BuildRequires

* Fri Sep 09 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 3.0-0.20050823.6mdk
- x86_64 fixes for binutils 2.16.9x
- requires glibc-xen for */nosegneg/ libs

* Fri Aug 12 2005 Flvio Bruno Leitner <fbl@mandriva.com> 3.0-0.20050823.5mdk
- updated to snapshot of 2005-08-23 (last know working)

* Fri Aug 12 2005 Flvio Bruno Leitner <fbl@mandriva.com> 3.0-0.20050829.4mdk
- updated to snapshot of 2005-08-29

* Fri Aug 12 2005 Flvio Bruno Leitner <fbl@mandriva.com> 3.0-0.20050811.3mdk
- updated to snapshot of 2005-08-19

* Fri Aug 12 2005 Flvio Bruno Leitner <fbl@mandriva.com> 3.0-0.20050811.2mdk
- updated to snapshot of 2005-08-11

* Sat Aug 06 2005 Flvio Bruno Leitner <fbl@mandriva.com> 3.0-0.20050801.1mdk
- created package.

